import { load } from './load';
import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

// Defining necessary for building pie chart
const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Rendering pie chart information
const render = (data,total) => {
  const pieData = pie().value(d=>d['Total Cases'])(data);
  

  // Pie chart constant variables
  const colors = scaleOrdinal()
  	.domain(data)
  	.range(["maroon","blue",
      "pink",
      "green",
      "black",
      "red",
      "purple",
      "navy",
      "orange","gray"
    ]);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data['Total Cases']));
    const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  // Building up legends for pie chart
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data['Total Cases']));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat((d.data['Total Cases']/1000))+"K");
}

// Running application
const run = async () => {
  let data = await load()
  let total = 0
  data.forEach(d=>{
    d['Total Cases'] = +d['Total Cases'];
    total += d['Total Cases']
  });
  console.log(data)
  
	render(data,total);
};
run();